@@ -15,7 +15,7 @@ MODULE el_phon
   LOGICAL :: elph, elph_mat, elph_simple
   INTEGER :: elph_nbnd_min, elph_nbnd_max
   INTEGER :: el_ph_ngauss, el_ph_nsigma
-  INTEGER :: iunwfcwann
+  INTEGER :: iunwfcwann, lrwfcr
   INTEGER :: npwq_refolded, ikqg
   INTEGER, allocatable :: wan_index_dyn(:)
   INTEGER, allocatable :: kpq(:), g_kpq(:,:),igqg(:)
