@@ -17,16 +17,23 @@ SUBROUTINE elphon()
   USE ions_base, ONLY : nat, ntyp => nsp, ityp, tau, amass
   USE gvecs, ONLY: doublegrid
   USE fft_base, ONLY : dfftp, dffts
-  USE noncollin_module, ONLY : nspin_mag
+  USE noncollin_module, ONLY : nspin_mag, noncolin
+  USE lsda_mod, ONLY : nspin
+  USE phus,       ONLY : int3, int3_nc, int3_paw
+  USE uspp,  ONLY: okvan
+  USE paw_variables, ONLY : okpaw
   USE dynmat, ONLY : dyn, w2
   USE qpoint, ONLY : xq
-  USE modes,  ONLY : npert, nirr
+  USE modes,  ONLY : npert, nirr, u
+  USE uspp_param, ONLY : nhm
   USE control_ph, ONLY : trans
   USE units_ph, ONLY : iudyn, lrdrho, iudvscf
+  USE dfile_star,    ONLY : dvscf_star
+  USE io_global, ONLY: stdout
   !
   IMPLICIT NONE
   !
-  INTEGER :: irr, imode0, ipert, is
+  INTEGER :: irr, imode0, ipert, is, npe
   ! counter on the representations
   ! counter on the modes
   ! the change of Vscf due to perturbations
@@ -35,20 +42,33 @@ SUBROUTINE elphon()
 
   CALL start_clock ('elphon')
 
+  if(dvscf_star%basis.eq.'cartesian') then
+     write(stdout,*) 'Setting patterns to identity'
+     u=CMPLX(0.d0,0.d0)
+     do irr=1,3*nat
+        u(irr,irr)=CMPLX(1.d0,0.d0)
+     enddo
+  endif
   !
   ! read Delta Vscf and calculate electron-phonon coefficients
   !
   imode0 = 0
   DO irr = 1, nirr
-     ALLOCATE (dvscfin (dfftp%nnr, nspin_mag , npert(irr)) )
-     DO ipert = 1, npert (irr)
+     npe=npert(irr)
+     ALLOCATE (dvscfin (dfftp%nnr, nspin_mag , npe) )
+     IF (okvan) THEN
+        ALLOCATE (int3 ( nhm, nhm, npe, nat, nspin_mag))
+        IF (okpaw) ALLOCATE (int3_paw (nhm, nhm, npe, nat, nspin_mag))
+        IF (noncolin) ALLOCATE(int3_nc( nhm, nhm, npe, nat, nspin))
+     ENDIF
+     DO ipert = 1, npe
         CALL davcio_drho ( dvscfin(1,1,ipert),  lrdrho, iudvscf, &
                            imode0 + ipert,  -1 )
      END DO
      IF (doublegrid) THEN
         ALLOCATE (dvscfins (dffts%nnr, nspin_mag , npert(irr)) )
         DO is = 1, nspin_mag
-           DO ipert = 1, npert(irr)
+           DO ipert = 1, npe
               CALL cinterpolate (dvscfin(1,is,ipert),dvscfins(1,is,ipert),-1)
            ENDDO
         ENDDO
@@ -58,9 +78,14 @@ SUBROUTINE elphon()
      CALL newdq (dvscfin, npert(irr))
      CALL elphel (npert (irr), imode0, dvscfins)
      !
-     imode0 = imode0 + npert (irr)
+     imode0 = imode0 + npe
      IF (doublegrid) DEALLOCATE (dvscfins)
      DEALLOCATE (dvscfin)
+     IF (okvan) THEN
+        DEALLOCATE (int3)
+        IF (okpaw) DEALLOCATE (int3_paw)
+        IF (noncolin) DEALLOCATE(int3_nc)
+     ENDIF
   ENDDO
   !
   ! now read the eigenvalues and eigenvectors of the dynamical matrix
@@ -79,7 +104,7 @@ SUBROUTINE readmat (iudyn, ibrav, celldm, nat, ntyp, ityp, omega, &
   !-----------------------------------------------------------------------
   !
   USE kinds, ONLY : DP
-  USE constants, ONLY : amconv
+  USE constants, ONLY : amu_ry
   IMPLICIT NONE
   ! Input
   INTEGER :: iudyn, ibrav, nat, ntyp, ityp (nat)
@@ -107,7 +132,7 @@ SUBROUTINE readmat (iudyn, ibrav, celldm, nat, ntyp, ityp, omega, &
           CALL errore ('readmat', 'inconsistent data', 1)
   DO nt = 1, ntyp
      READ (iudyn, * ) i, atm, amass_
-     IF ( nt.NE.i .OR. ABS (amass_ - amconv*amass (nt) ) > 1.0d-5) &
+     IF ( nt.NE.i .OR. ABS (amass_ - amu_ry*amass (nt) ) > 1.0d-5) &
         CALL errore ( 'readmat', 'inconsistent data', 1 + nt)
   ENDDO
   DO na = 1, nat
@@ -138,9 +163,9 @@ SUBROUTINE readmat (iudyn, ibrav, celldm, nat, ntyp, ityp, omega, &
         DO na = 1, nat
            DO i = 1, 3
               dynr (1, i, na, j, nb) = dynr (1, i, na, j, nb) / SQRT (amass ( &
-                   ityp (na) ) * amass (ityp (nb) ) ) / amconv
+                   ityp (na) ) * amass (ityp (nb) ) ) / amu_ry
               dynr (2, i, na, j, nb) = dynr (2, i, na, j, nb) / SQRT (amass ( &
-                   ityp (na) ) * amass (ityp (nb) ) ) / amconv
+                   ityp (na) ) * amass (ityp (nb) ) ) / amu_ry
            ENDDO
         ENDDO
      ENDDO
@@ -156,7 +181,7 @@ SUBROUTINE readmat (iudyn, ibrav, celldm, nat, ntyp, ityp, omega, &
   DO nu = 1, 3 * nat
      DO mu = 1, 3 * nat
         na = (mu - 1) / 3 + 1
-        dyn (mu, nu) = dyn (mu, nu) / SQRT ( amconv * amass (ityp (na) ) )
+        dyn (mu, nu) = dyn (mu, nu) / SQRT ( amu_ry * amass (ityp (na) ) )
      ENDDO
   ENDDO
   !
@@ -742,7 +767,7 @@ SUBROUTINE elphsum_simple
   USE symm_base, ONLY : s, sr, irt, nsym, time_reversal, invs
   USE klist, ONLY : xk, nelec, nks, wk
   USE wvfct, ONLY : nbnd, et
-  USE el_phon
+  USE el_phon, ONLY : el_ph_mat, el_ph_nsigma, el_ph_ngauss, el_ph_sigma
   USE mp_global, ONLY : me_pool, root_pool, inter_pool_comm, npool, intra_pool_comm
   USE io_global, ONLY : stdout
   USE klist, only : degauss,ngauss
@@ -751,7 +776,7 @@ SUBROUTINE elphsum_simple
   USE io_files,  ONLY : prefix
   USE qpoint, ONLY : xq, nksq
   USE dynmat, ONLY : dyn, w2
-  USE modes, ONLY : u,rtau, irgq, nsymq,irotmq, minus_q
+  USE modes, ONLY : u,rtau, nsymq,irotmq, minus_q
   USE control_ph, only : lgamma
   USE lsda_mod, only : isk,nspin, current_spin,lsda
   USE mp,        ONLY: mp_sum
@@ -786,6 +811,7 @@ SUBROUTINE elphsum_simple
 
   nmodes=3*nat
 
+
   write(filelph,'(A5,f9.6,A1,f9.6,A1,f9.6)') 'elph.',xq(1),'.',xq(2),'.',xq(3)
 
   ! parallel case: only first node writes
@@ -879,7 +905,7 @@ SUBROUTINE elphsum_simple
      ! symmetrize el_ph_sum(mu,nu) : it transforms as the dynamical matrix
      !
      
-     CALL symdyn_munu (el_ph_sum, u, xq, s, invs, rtau, irt, irgq, at, &
+     CALL symdyn_munu_new (el_ph_sum, u, xq, s, invs, rtau, irt,  at, &
           bg, nsymq, nat, irotmq, minus_q)
      !
      WRITE (6, 9000) degauss1, ngauss1
