@@ -121,11 +121,12 @@ SUBROUTINE ep_matrix_element_wannier()
   IF (.NOT.trans) CALL readmat (iudyn, ibrav, celldm, nat, ntyp, &
        ityp, omega, amass, tau, xq, w2, dyn)
   !
+  
 
   deallocate(xk_gamma)
   deallocate(kpq,g_kpq,igqg)
 
-  CALL stop_clock ('elphon')
+! CALL stop_clock ('elphon')
   RETURN
 END SUBROUTINE ep_matrix_element_wannier
 
@@ -141,16 +142,16 @@ SUBROUTINE elphsum_wannier(q_index)
   USE kinds, ONLY : DP
   USE ions_base, ONLY : nat, ityp, tau,amass,tau, ntyp => nsp, atm
   USE cell_base, ONLY : at, bg, ibrav, celldm 
-  USE symm_base, ONLY : s, sr, irt, nsym, time_reversal, invs, ftau
+  USE symm_base, ONLY : s, sr, irt, nsym, time_reversal, invs, ftau, copy_sym, inverse_s
   USE klist, ONLY : xk, nelec
   USE wvfct, ONLY : nbnd, et
   USE el_phon
   USE mp_global, ONLY : me_pool, root_pool, inter_pool_comm, npool, intra_pool_comm
-  USE io_global, ONLY : stdout
+  USE io_global, ONLY : stdout,ionode
   USE io_files,  ONLY : prefix
   USE qpoint, ONLY : xq, nksq
   USE dynmat, ONLY : dyn, w2
-  USE modes, ONLY : u
+  USE modes, ONLY : u, gi, gimq, irgq, irotmq
   USE control_ph, only : lgamma
   USE lsda_mod, only : isk,nspin, current_spin,lsda
   USE mp,        ONLY: mp_sum
@@ -164,7 +165,7 @@ SUBROUTINE elphsum_wannier(q_index)
   integer :: nq, imq, isq(48)
   INTEGER :: ik, ikk, ikq, ibnd, jbnd, ipert, jpert, nu, mu, &
          ios, iuelphmat,i,j,nt,k
-  INTEGER :: iu_sym,nmodes
+  INTEGER :: iu_sym,nmodes,nsymq
   INTEGER :: io_file_unit
   !   for star_q
   REAL(DP) :: rtauloc(3,48,nat)
@@ -186,7 +187,7 @@ SUBROUTINE elphsum_wannier(q_index)
 
   
   ! parallel case: only first node writes
-  IF ( me_pool /= root_pool ) THEN
+  IF ( .not.ionode ) THEN
      iuelphmat = 0
   ELSE
      !
@@ -230,18 +231,30 @@ SUBROUTINE elphsum_wannier(q_index)
                 ibnd=elph_nbnd_min,elph_nbnd_max)
         enddo
      enddo
-     
+  
+
+
      !
      ! Then I dump symmetry operations
      !
-     sym(1:nsym)=.true.
-     call smallg_q (xq, 0, at, bg, nsym, s, ftau, sym, minus_qloc)
-     IF ( .not. time_reversal ) minus_qloc = .false.
+     minus_qloc = .true.
+     sym = .false.
+     sym(1:nsym) = .true.
      
+     call smallg_q (xq, 0, at, bg, nsym, s, ftau, sym, minus_qloc)
+     nsymq = copy_sym(nsym, sym)
+     ! recompute the inverses as the order of sym.ops. has changed
+     CALL inverse_s ( )
+     
+     ! part 2: this redoes most of the above, plus it computes irgq, gi, gimq
+     CALL smallgq (xq, at, bg, s, nsym, irgq, nsymq, irotmq, &
+          minus_qloc, gi, gimq)
+     
+     sym(1:nsym)=.true.
      call sgam_ph (at, bg, nsym, s, irt, tau, rtauloc, nat, sym)
      call star_q(xq, at, bg, nsym , s , invs , nq, sxq, &
           isq, imq, .FALSE. )
-
+     
      
      do j=1,3
         write(iuelphmat) (at(i,j),i=1,3)
@@ -251,7 +264,7 @@ SUBROUTINE elphsum_wannier(q_index)
      enddo
      write(iuelphmat) nsym,nq,imq
      do i=1,nsym
-        write(iuelphmat) i,invs,isq(i)
+        write(iuelphmat) i,invs(i),isq(i)
         do j=1,3
            do k=1,3
               write(iuelphmat) k,j, s(k,j,i)
@@ -271,9 +284,9 @@ SUBROUTINE elphsum_wannier(q_index)
      enddo
      
      close(iuelphmat)
-     
-     !
-  END IF
+  endif
+  
+  !
   !
   
 
@@ -301,7 +314,7 @@ SUBROUTINE elphel_refolded (npe, imode0, dvscfins)
   USE wvfct, ONLY: nbnd, npw, npwx, igk
   USE uspp, ONLY : vkb
   USE el_phon, ONLY : el_ph_mat, iunwfcwann, igqg, kpq, g_kpq, &
-           xk_gamma, npwq_refolded
+           xk_gamma, npwq_refolded, lrwfcr
   USE modes, ONLY : u
   USE units_ph, ONLY : iubar, lrbar, lrwfc, iuwfc
   USE eqv,      ONLY : dvpsi!, evq
@@ -383,8 +396,8 @@ SUBROUTINE elphel_refolded (npe, imode0, dvscfins)
 !    We read here the wfc at the Gamma point, that is
 !    that saved by Wannier.
 
-     CALL davcio (evc, lrwfc, iunwfcwann, ik, - 1)
-     CALL davcio (evq, lrwfc, iunwfcwann, ikqg, - 1)
+!     CALL davcio (evc, lrwfc, iunwfcwann, ik, - 1)
+!     CALL davcio (evq, lrwfc, iunwfcwann, ikqg, - 1)
 
 
 
@@ -398,9 +411,10 @@ SUBROUTINE elphel_refolded (npe, imode0, dvscfins)
 !     ENDIF
      !
 
+     call read_wfc_rspace_and_fwfft( evc , ik , lrwfcr , iunwfcwann , npw , igk )
 
 
-    call calculate_and_apply_phase(ik, ikqg, igqg, npwq_refolded, g_kpq,xk_gamma, evq)
+     call calculate_and_apply_phase(ik, ikqg, igqg, npwq_refolded, g_kpq,xk_gamma, evq, .true.)
      
 
      DO ipert = 1, npe
@@ -467,6 +481,14 @@ subroutine get_equivalent_kpq(xk,xq,kpq,g_kpq, igqg)
     !                                                                  !
     !  Set up the k+q shell for electron-phonon coupling               ! 
     !                                                                  !
+    !  This routine finds the G vectors such that                      !
+    !  k+q+G=k'  with k and k' belonging to nksq                       !
+    !  for each k, the G vector is stored in g_kpq                     !
+    !  k'=kpq(ik)                                                      !
+    !  and finally igqg(ik) is the index that allows to find           !
+    !  the g vector g_kpq in the list of all the G vectors             !
+    !                                                                  !
+    !       Matteo Calandra                                            !
     !===================================================================  
   USE kinds, ONLY : DP
   USE io_global, ONLY : stdout
@@ -474,6 +496,8 @@ subroutine get_equivalent_kpq(xk,xq,kpq,g_kpq, igqg)
   USE qpoint, ONLY : nksq, ikks
   USE gvect, ONLY: g, gg
   USE qpoint, ONLY : nksq
+  USE mp_global, ONLY : intra_pool_comm
+  USE mp, ONLY : mp_sum
   ! WARNING g_kpq mesh is an integer
   implicit none
   
@@ -481,6 +505,7 @@ subroutine get_equivalent_kpq(xk,xq,kpq,g_kpq, igqg)
   
   integer :: iqx,iqy,iqz,i,j,k,n,nn,iq,ik, ig
   integer :: kpq(nksq),g_kpq(3,nksq),igqg(nksq)
+  integer, allocatable :: ig_check(:)
   real(kind=dp) :: gg_
   real(kind=dp) :: xq(3), xk(3,*)
   real(kind=dp) :: xkpq(3),Gvec(3),xq_crys(3)
@@ -490,6 +515,10 @@ subroutine get_equivalent_kpq(xk,xq,kpq,g_kpq, igqg)
   ! nksq = number of k point per pool withour k+q
   !
 
+  ! 
+  ! The xk_point entering here must be the k and not
+  !    the k+q
+  !
 
   xq_crys=xq
 
@@ -539,6 +568,7 @@ subroutine get_equivalent_kpq(xk,xq,kpq,g_kpq, igqg)
   !
   ! here between all the g-vectors I find the index of that
   ! related to the translation in the Brillouin zone.
+  ! Warning: if G does not belong to the processor igqg is zero.
   !
 
   igqg=0
@@ -559,14 +589,21 @@ subroutine get_equivalent_kpq(xk,xq,kpq,g_kpq, igqg)
      end do
   end do
 
+  allocate(ig_check(nksq))
+  ig_check=igqg
+  CALL mp_sum( ig_check, intra_pool_comm )
+  do ik=1,nksq
+     if(ig_check(ik).eq.0) &
+          CALL errore('get_equivalent_kpq', &
+          ' g_kpq vector is not in the list of Gs', 100*ik )
 
-
+  enddo
   deallocate(xk_crys)
 
   
 end subroutine get_equivalent_kpq
 
-subroutine calculate_and_apply_phase(ik, ikqg, igqg, npwq_refolded, g_kpq, xk_gamma, evq)
+subroutine calculate_and_apply_phase(ik, ikqg, igqg, npwq_refolded, g_kpq, xk_gamma, evq, lread)
   USE kinds, ONLY : DP
   USE fft_base, ONLY : dffts
   USE fft_interfaces,        ONLY : fwfft, invfft
@@ -575,11 +612,14 @@ subroutine calculate_and_apply_phase(ik, ikqg, igqg, npwq_refolded, g_kpq, xk_ga
   USE gvecs, ONLY : nls
   USE cell_base, ONLY : bg, tpiba2
   USE qpoint, ONLY : nksq, npwq
+   USE wavefunctions_module, ONLY : evc
 !  USE eqv,      ONLY : evq
   USE noncollin_module,     ONLY : npol
+  USE el_phon, ONLY:iunwfcwann, lrwfcr
 
   IMPLICIT NONE
 
+  LOGICAL :: lread
   INTEGER :: ik, ikqg,   npwq_refolded
   INTEGER :: igqg(nksq)
   INTEGER :: g_kpq(3,nksq)
@@ -611,6 +651,10 @@ subroutine calculate_and_apply_phase(ik, ikqg, igqg, npwq_refolded, g_kpq, xk_ga
 
   call gk_sort (xk_gamma(1,ikqg), ngm, g_scra, ecutwfc / tpiba2, npw_, igk_, g2kin)
 
+  if(lread) then
+     call read_wfc_rspace_and_fwfft( evq , ikqg , lrwfcr , iunwfcwann , npw_ , igk_ )
+  endif
+
   call gk_sort (xkqg, ngm, g_scra, ecutwfc / tpiba2, npwq_refolded, igkq_, g2kin)
 
   phase(:) = CMPLX(0.d0,0.d0)
