@@ -222,7 +222,7 @@ MODULE ph_restart
             !
             CALL iotk_write_dat(iunpun,"QPOINT_GROUP_RANK",nsymq)
             !
-            IF (trans.OR.zeu.OR.elph) THEN
+!            IF (trans.OR.zeu.OR.elph) THEN
               !
                CALL iotk_write_dat(iunpun,"NUMBER_IRR_REP",nirr)
               !
@@ -231,7 +231,7 @@ MODULE ph_restart
                   CALL iotk_write_dat(iunpun,"NUMBER_OF_PERTURBATIONS",&
                                          npert(irr))
                   CALL iotk_write_dat(iunpun,"SYMMETRY_TYPE",&
-                                         name_rap_mode(irr))
+                                         name_rap_mode(imode0+1))
                   DO ipert=1,npert(irr)
                      imode=imode0+ipert
                      CALL iotk_write_dat(iunpun,"DISPLACEMENT_PATTERN",&
@@ -239,7 +239,7 @@ MODULE ph_restart
                   ENDDO
                   imode0=imode0+npert(irr)
                ENDDO
-            ENDIF
+!            ENDIF
 !
 !   Save the current flags
 !
@@ -811,21 +811,23 @@ MODULE ph_restart
               'problems with current_iq', 1 )
 
     IF (ionode) THEN
-       IF (trans.OR.zeu.OR.elph) THEN
+!       IF (trans.OR.zeu.OR.elph) THEN
           CALL iotk_scan_dat(iunpun,"NUMBER_IRR_REP",nirr)
           imode0=0
           DO irr=0,nirr
              IF (irr > 0) THEN
                 CALL iotk_scan_dat(iunpun,"NUMBER_OF_PERTURBATIONS", npert(irr))
-                CALL iotk_scan_dat(iunpun,"SYMMETRY_TYPE", name_rap_mode(irr))
+                CALL iotk_scan_dat(iunpun,"SYMMETRY_TYPE",&
+                                                    name_rap_mode(imode0+1))
                 DO ipert=1,npert(irr)
                    imode=imode0+ipert
                    CALL iotk_scan_dat(iunpun,"DISPLACEMENT_PATTERN",u(:,imode))
+                   IF (ipert > 1) name_rap_mode(imode)=name_rap_mode(imode0+1)
                 ENDDO
                 imode0=imode0+npert(irr)
              ENDIF
           ENDDO
-       ENDIF
+!       ENDIF
 !
 !   read all flags
 !
@@ -869,11 +871,12 @@ MODULE ph_restart
        IF (done_elop) CALL mp_bcast( eloptns,  ionode_id, intra_image_comm )
     ENDIF
 
-    IF (trans.OR.zeu.OR.elph) THEN
+!    IF (trans.OR.zeu.OR.elph) THEN
        CALL mp_bcast( nirr,  ionode_id, intra_image_comm )
        CALL mp_bcast( npert,  ionode_id, intra_image_comm )
        CALL mp_bcast( u,  ionode_id, intra_image_comm )
-    ENDIF
+       CALL mp_bcast( name_rap_mode,  ionode_id, intra_image_comm )
+!    ENDIF
 
     RETURN
     END SUBROUTINE read_u
