@@ -18,7 +18,6 @@ SUBROUTINE phq_readin()
   !
   USE kinds,         ONLY : DP
   USE parameters,    ONLY : nsx
-  USE constants,     ONLY : amconv
   USE ions_base,     ONLY : nat, ntyp => nsp
   USE io_global,     ONLY : ionode_id
   USE mp,            ONLY : mp_bcast
@@ -52,9 +51,11 @@ SUBROUTINE phq_readin()
   USE ldaU,          ONLY : lda_plus_u
   USE control_flags, ONLY : iverbosity, modenum, twfcollect
   USE io_global,     ONLY : ionode, stdout
-  USE mp_global,     ONLY : nproc, nproc_pool, nproc_pool_file, &
+  USE mp_global,     ONLY : nproc_pool, nproc_pool_file, &
                             nimage, my_image_id,    &
-                            nproc_image_file, nproc_image
+                            nproc_image_file, nproc_image, npool, &
+                            get_ntask_groups, ntask_groups_file,  &
+                            nproc_bgrp_file
   USE paw_variables, ONLY : okpaw
   USE ramanm,        ONLY : eth_rps, eth_ns, lraman, elop, dek
   USE freq_ph,       ONLY : fpol, fiu, nfs, nfsmax
@@ -100,9 +101,6 @@ SUBROUTINE phq_readin()
                        drho_star, dvscf_star, &
                        elph_nbnd_min, elph_nbnd_max, el_ph_ngauss,el_ph_nsigma, el_ph_sigma,  &
                        electron_phonon
-!
-!  elph, elph_mat
-!
 
   ! tr2_ph       : convergence threshold
   ! amass        : atomic masses
@@ -255,7 +253,7 @@ SUBROUTINE phq_readin()
       drho_star%dir = TRIM(outdir)//"/Rotated_DRHO/"
   !
   dvscf_star%open = .FALSE.
-  dvscf_star%basis = 'cartesian'
+  dvscf_star%basis = 'modes'
   dvscf_star%pat  = .FALSE.
   dvscf_star%ext = 'dvscf'
   CALL get_env( 'ESPRESSO_FILDVSCF_DIR', dvscf_star%dir)
@@ -302,8 +300,36 @@ SUBROUTINE phq_readin()
   IF (modenum < 0) CALL errore ('phq_readin', ' Wrong modenum ', 1)
   IF (dek <= 0.d0) CALL errore ( 'phq_readin', ' Wrong dek ', 1)
   !
+  SELECT CASE( trim( electron_phonon ) )
+  CASE( 'simple' )
+     elph=.true.
+     elph_mat=.false.
+     elph_simple=.true. 
+  CASE( 'Wannier' )
+     elph=.true.
+     elph_mat=.true.
+     elph_simple=.false.
+     auxdvscf=trim(fildvscf)
+  CASE( 'interpolated' )
+     elph=.true.
+     elph_mat=.false.
+     elph_simple=.false.
+  CASE DEFAULT
+     elph=.false.
+     elph_mat=.false.
+     elph_simple=.false.
+  END SELECT
+
   epsil = epsil .OR. lraman .OR. elop
-  trans = trans .OR. ldisp
+
+  IF (modenum /= 0) search_sym=.FALSE.
+  
+  if(elph_simple.or.elph_mat) then
+     trans=.false.
+  else
+     trans = trans .OR. ldisp
+  endif
+   
   !
   ! Set default value for fildrho and fildvscf if they are required
   IF ( (lraman.OR.elop.OR.drho_star%open) .AND. fildrho == ' ') fildrho = 'drho'
@@ -343,6 +369,8 @@ SUBROUTINE phq_readin()
   ! reads the frequencies ( just if fpol = .true. )
   !
   IF ( fpol ) THEN
+     IF ( .NOT. epsil) CALL errore ('phq_readin', &
+                                    'fpol=.TRUE. needs epsil=.TRUE.', 1 )
      nfs=0
      IF (ionode) THEN
         READ (5, *, iostat = ios) card
@@ -451,25 +479,11 @@ SUBROUTINE phq_readin()
      CALL errore('phq_readin',&
      'pw.x run with a different number of pools. Use wf_collect=.true.',1)
 
-  SELECT CASE( trim( electron_phonon ) )
-  CASE( 'simple' )
-     elph=.true.
-     elph_mat=.false.
-     elph_simple=.true. 
-  CASE( 'Wannier' )
-     elph=.true.
-     elph_mat=.true.
-     elph_simple=.false.
-     auxdvscf=trim(fildvscf)
-  CASE( 'interpolated' )
-     elph=.true.
-     elph_mat=.false.
-     elph_simple=.false.
-  CASE DEFAULT
-     elph=.false.
-     elph_mat=.false.
-     elph_simple=.false.
-  END SELECT
+  IF (get_ntask_groups() > 1) &
+     CALL errore('phq_readin','task_groups not available in phonon',1)
+
+  IF (nproc_bgrp_file /= nproc_pool_file) &
+     CALL errore('phq_readin','band parallelization not available in phonon',1)
 
   IF (elph.and.nimage>1) CALL errore('phq_readin',&
        'el-ph with image parallelization is not yet available',1)
@@ -477,8 +491,8 @@ SUBROUTINE phq_readin()
   if(elph_mat.and.fildvscf.eq.' ') call errore('phq_readin',&
        'el-ph with wannier requires fildvscf',1)
 
-  IF(elph_mat.and.nproc.ne.1) call errore('phq_readin',&
-       'el-ph with wannier only on single processor',1)
+  IF(elph_mat.and.npool.ne.1) call errore('phq_readin',&
+       'el-ph with wannier : pools not implemented',1)
   
   IF (elph.OR.fildvscf /= ' ') lqdir=.TRUE.
 
