@@ -12,7 +12,9 @@ SUBROUTINE stop_ph( flag )
   ! ... Synchronize processes before stopping.
   !
   USE kinds, ONLY : DP
-  USE mp_global, ONLY : mp_global_end
+  USE mp_global, ONLY : mp_global_end, nimage
+  USE environment,        ONLY : environment_end
+  USE image_io_routines,  ONLY : io_image_stop
   !
   IMPLICIT NONE
   !
@@ -21,6 +23,10 @@ SUBROUTINE stop_ph( flag )
   !
   CALL print_clock_ph()
   !
+  CALL environment_end('PHONON')
+  !
+  IF (nimage > 1) CALL io_image_stop()
+  !
   CALL mp_global_end()
   !
   CALL deallocate_part()
